plot.exdqlmDiagnostic: Plot Method for 'exdqlmDiagnostic' Objects

View source: R/exdqlmDiagnostic_methods.R

plot.exdqlmDiagnosticR Documentation

Plot Method for exdqlmDiagnostic Objects

Description

This function produces the QQ plot and ACF plot corresponding to the one-step-ahead distribution sequence, together with a time series plot of the MAP standard forecast errors.

Usage

## S3 method for class 'exdqlmDiagnostic'
plot(x, ...)

Arguments

x

An exdqlmDiagnostic object.

...

Additional graphical arguments. The optional cols element controls the colors used for the first and second model when comparing two fits.

Value

Invisibly returns x.

Examples


data("scIVTmag", package = "exdqlm")
old = options(exdqlm.max_iter = 15L)
y = scIVTmag[1:60]
model = polytrendMod(1, stats::quantile(y, 0.85), 10)
M0 = exdqlmLDVB(y, p0 = 0.85, model, df = c(0.95), dim.df = c(1),
                  gam.init = -3.5, sig.init = 15,
                  n.samp = 20, tol = 0.2, verbose = FALSE)
M0.diags = diagnostics(M0)
plot(M0.diags)
options(old)



exdqlm documentation built on July 10, 2026, 1:08 a.m.