View source: R/exdqlmFit_methods.R
| summary.exdqlmFit | R Documentation |
exdqlmFit ObjectsPrints a compact summary of a fitted dynamic quantile state-space model and returns the displayed summary tables for programmatic inspection.
## S3 method for class 'exdqlmFit'
summary(object, ...)
object |
A fitted dynamic |
... |
Additional arguments (unused). |
Invisibly returns a list with data frames describing stored draws, scalar posterior summaries, and convergence information.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.