Learn R Programming

exdqlm (version 0.4.0)

summary.exdqlmSynthesis: Summary Method for exdqlmSynthesis Objects

Description

Summary Method for exdqlmSynthesis Objects

Usage

# S3 method for exdqlmSynthesis
summary(object, time = NULL, ...)

Value

A data frame containing pointwise summaries of the synthesized posterior predictive draws.

Arguments

object

An exdqlmSynthesis object.

time

Optional vector of time values. If supplied, it must have length equal to the number of rows in object$draws.

...

Additional arguments (unused).