| diagnostics | R Documentation |
Compute diagnostic summaries for fitted and post-processing objects.
diagnostics(object, ...)
object |
An object of class |
... |
Additional arguments passed to specific methods. |
diagnostics() is the standard diagnostic entry point for the main
fitted-object families in exdqlm. Methods are currently provided for
dynamic fitted models, dynamic forecast objects, and static AL/exAL fitted
models. The returned objects can be inspected with print() or
summary(), and plotted with plot() when a diagnostic display is
defined.
The output depends on the method: diagnostics.exdqlmFit()
returns an exdqlmDiagnostic object,
diagnostics.exdqlmForecast() returns an
exdqlmForecastDiagnostic object, and
diagnostics.exalStaticFit() returns an
exalStaticDiagnostic object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.