| seasMod | R Documentation |
The function creates a Fourier form periodic component for given period and harmonics.
seasMod(p, h, m0, C0, backend = c("auto", "R", "cpp"))
p |
Numeric period. |
h |
Numeric vector of harmonics to be included. |
m0 |
Optional numeric prior mean. Defaults to |
C0 |
Optional numeric prior covariance. Defaults to matrix |
backend |
Backend selection for matrix construction:
|
An object of class "exdqlm" containing the following:
FF - q \times 1 observational vector.
GG - q \times q evolution matrix.
m0 - q \times 1 prior mean of the state vector.
C0 - q \times q prior covariance matrix of the state vector.
# create a seasonal component with first, second and fourth harmonics of a period of 365
seas.comp = seasMod(365, c(1, 2, 4), C0 = 10*diag(6))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.